@@ -1,9 +1,5 @@
 #!/usr/bin/env perl
 
-# PERL_FUTURE_DEBUG=1 perl eg/tester.pl
-
-use v5.36;
-
 use curry;
 use Future::IO::Impl::IOAsync;
 use MIDI::RtController ();
@@ -15,15 +11,11 @@ my $output_name = shift || 'fluid';    # fluidsynth
 my $rtc = MIDI::RtController->new(
     input  => $input_name,
     output => $output_name,
+    verbose => 1,
 );
 
 my $rtfd = MIDI::RtController::Filter::Drums->new(rtc => $rtc);
 
-add_filters('drums', $rtfd->curry::drums, 0);
+$rtc->add_filter('drums', note_on => $rtfd->curry::drums);
 
 $rtc->run;
-
-sub add_filters ($name, $coderef, $types) {
-    $types ||= [qw(note_on note_off)];
-    $rtc->add_filter($name, $types, $coderef);
-}
