@@ -5,7 +5,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 use v5.36;
 
-our $VERSION = '0.0200';
+our $VERSION = '0.0202';
 
 use strictures 2;
 use List::SomeUtils qw(first_index);
@@ -70,10 +70,9 @@ sub _drum_parts ($self, $note) {
 }
 sub drums ($self, $device, $dt, $event) {
     my ($ev, $chan, $note, $val) = $event->@*;
-    return 0 if $self->trigger && $note != $self->trigger;
-    return 0 if $self->value && $val != $self->value;
+    return 0 if defined $self->trigger && $note != $self->trigger;
+    return 0 if defined $self->value && $val != $self->value;
 
-    return 1 unless $ev eq 'note_on';
     my $part = $self->_drum_parts($note);
     my $d = MIDI::Drummer::Tiny->new(
         bpm  => $self->bpm,
@@ -104,11 +103,12 @@ MIDI::RtController::Filter::Drums - RtController drum filters
 
 =head1 VERSION
 
-version 0.0200
+version 0.0202
 
 =head1 SYNOPSIS
 
   use curry;
+  use Future::IO::Impl::IOAsync;
   use MIDI::RtController ();
   use MIDI::RtController::Filter::Drums ();
 
@@ -126,7 +126,8 @@ version 0.0200
 =head1 DESCRIPTION
 
 C<MIDI::RtController::Filter::Drums> is the L<MIDI::RtController>
-filter for the drums.
+filter for the drums. It is meant to be an example of how to make a
+drum filter and uses the 4/4 metronome for this.
 
 =head1 ATTRIBUTES
 
